// jack.c
// LiVES (lives-exe)
// (c) G. Finch 2005
// Released under the GPL 2.0
// see file ../COPYING for licensing details

#include "main.h"
#include "jack.h"
#include "callbacks.h"

static jack_client_t *jack_client;

void lives_jack_init (void) {
  unsetenv ("JACK_NO_START_SERVER");
  setenv ("JACK_START_SERVER","1",0);
  jack_client=jack_client_new("LiVES");

  jack_set_sync_callback (jack_client, lives_start_ready_callback, NULL);

  gtk_timeout_add(KEY_RPT_INTERVAL,&lives_jack_poll,NULL);

}

void jack_transport_check_state (void) {
  jack_position_t pos;
  jack_transport_state_t jacktstate;

  if (!prefs->jack_transport_state&JACK_TRANSPORT_STATE_CLIENT) return;

  jacktstate=jack_transport_query (jack_client, &pos);

  if (mainw->jack_can_start&&(jacktstate==JackTransportRolling||jacktstate==JackTransportStarting)&&mainw->playing_file==-1&&mainw->current_file>0) {
    mainw->jack_can_stop=TRUE;
    on_playall_activate(NULL,NULL);
  }
  if (jacktstate==JackTransportStopped) {
     if (mainw->playing_file>-1&&mainw->jack_can_stop) on_stop_activate (NULL,NULL);
     mainw->jack_can_start=TRUE;
  }
}

gboolean lives_jack_poll(gpointer data) {
  // data is always NULL
  // must return TRUE
  if (!mainw->is_processing) jack_transport_check_state();
  return TRUE;
}

void lives_jack_end (void) {
  jack_client_close (jack_client);
}

int lives_start_ready_callback (jack_transport_state_t state, jack_position_t *pos, void *arg) {
  // we will return FALSE until the first frame is loaded, and the audio seek is ready

  //return mainw->video_seek_ready|mainw->audio_seek_ready;
  return TRUE; // for now
}

void jack_pb_start (void) {
  // call this ASAP, then in load_frame_image; we will wait for sync from other clients (and ourself !)
  if (prefs->jack_transport_state&JACK_TRANSPORT_STATE_MASTER) jack_transport_start (jack_client);
}

void jack_pb_stop (void) {
  // call this after pb stops
  if (prefs->jack_transport_state&JACK_TRANSPORT_STATE_MASTER) jack_transport_stop (jack_client);
}

